<?php

return [
    'Names' => [
        'af' => 'ಆಫ್ರಿಕಾನ್ಸ್',
        'af_NA' => 'ಆಫ್ರಿಕಾನ್ಸ್ (ನಮೀಬಿಯಾ)',
        'af_ZA' => 'ಆಫ್ರಿಕಾನ್ಸ್ (ದಕ್ಷಿಣ ಆಫ್ರಿಕಾ)',
        'ak' => 'ಅಕಾನ್',
        'ak_GH' => 'ಅಕಾನ್ (ಘಾನಾ)',
        'am' => 'ಅಂಹರಿಕ್',
        'am_ET' => 'ಅಂಹರಿಕ್ (ಇಥಿಯೋಪಿಯಾ)',
        'ar' => 'ಅರೇಬಿಕ್',
        'ar_001' => 'ಅರೇಬಿಕ್ (ಪ್ರಪಂಚ)',
        'ar_AE' => 'ಅರೇಬಿಕ್ (ಯುನೈಟೆಡ್ ಅರಬ್ ಎಮಿರೇಟ್ಸ್)',
        'ar_BH' => 'ಅರೇಬಿಕ್ (ಬಹ್ರೇನ್)',
        'ar_DJ' => 'ಅರೇಬಿಕ್ (ಜಿಬೂಟಿ)',
        'ar_DZ' => 'ಅರೇಬಿಕ್ (ಅಲ್ಜೀರಿಯ)',
        'ar_EG' => 'ಅರೇಬಿಕ್ (ಈಜಿಪ್ಟ್)',
        'ar_EH' => 'ಅರೇಬಿಕ್ (ಪಶ್ಚಿಮ ಸಹಾರಾ)',
        'ar_ER' => 'ಅರೇಬಿಕ್ (ಎರಿಟ್ರಿಯಾ)',
        'ar_IL' => 'ಅರೇಬಿಕ್ (ಇಸ್ರೇಲ್)',
        'ar_IQ' => 'ಅರೇಬಿಕ್ (ಇರಾಕ್)',
        'ar_JO' => 'ಅರೇಬಿಕ್ (ಜೋರ್ಡಾನ್)',
        'ar_KM' => 'ಅರೇಬಿಕ್ (ಕೊಮೊರೊಸ್)',
        'ar_KW' => 'ಅರೇಬಿಕ್ (ಕುವೈತ್)',
        'ar_LB' => 'ಅರೇಬಿಕ್ (ಲೆಬನಾನ್)',
        'ar_LY' => 'ಅರೇಬಿಕ್ (ಲಿಬಿಯಾ)',
        'ar_MA' => 'ಅರೇಬಿಕ್ (ಮೊರಾಕ್ಕೊ)',
        'ar_MR' => 'ಅರೇಬಿಕ್ (ಮಾರಿಟೇನಿಯಾ)',
        'ar_OM' => 'ಅರೇಬಿಕ್ (ಓಮನ್)',
        'ar_PS' => 'ಅರೇಬಿಕ್ (ಪ್ಯಾಲೇಸ್ಟೇನಿಯನ್ ಪ್ರದೇಶಗಳು)',
        'ar_QA' => 'ಅರೇಬಿಕ್ (ಖತಾರ್)',
        'ar_SA' => 'ಅರೇಬಿಕ್ (ಸೌದಿ ಅರೇಬಿಯಾ)',
        'ar_SD' => 'ಅರೇಬಿಕ್ (ಸುಡಾನ್)',
        'ar_SO' => 'ಅರೇಬಿಕ್ (ಸೊಮಾಲಿಯಾ)',
        'ar_SS' => 'ಅರೇಬಿಕ್ (ದಕ್ಷಿಣ ಸುಡಾನ್)',
        'ar_SY' => 'ಅರೇಬಿಕ್ (ಸಿರಿಯಾ)',
        'ar_TD' => 'ಅರೇಬಿಕ್ (ಚಾದ್)',
        'ar_TN' => 'ಅರೇಬಿಕ್ (ಟುನೀಶಿಯ)',
        'ar_YE' => 'ಅರೇಬಿಕ್ (ಯೆಮನ್)',
        'as' => 'ಅಸ್ಸಾಮೀಸ್',
        'as_IN' => 'ಅಸ್ಸಾಮೀಸ್ (ಭಾರತ)',
        'az' => 'ಅಜೆರ್ಬೈಜಾನಿ',
        'az_AZ' => 'ಅಜೆರ್ಬೈಜಾನಿ (ಅಜರ್ಬೈಜಾನ್)',
        'az_Cyrl' => 'ಅಜೆರ್ಬೈಜಾನಿ (ಸಿರಿಲಿಕ್)',
        'az_Cyrl_AZ' => 'ಅಜೆರ್ಬೈಜಾನಿ (ಸಿರಿಲಿಕ್, ಅಜರ್ಬೈಜಾನ್)',
        'az_Latn' => 'ಅಜೆರ್ಬೈಜಾನಿ (ಲ್ಯಾಟಿನ್)',
        'az_Latn_AZ' => 'ಅಜೆರ್ಬೈಜಾನಿ (ಲ್ಯಾಟಿನ್, ಅಜರ್ಬೈಜಾನ್)',
        'be' => 'ಬೆಲರೂಸಿಯನ್',
        'be_BY' => 'ಬೆಲರೂಸಿಯನ್ (ಬೆಲಾರಸ್)',
        'bg' => 'ಬಲ್ಗೇರಿಯನ್',
        'bg_BG' => 'ಬಲ್ಗೇರಿಯನ್ (ಬಲ್ಗೇರಿಯಾ)',
        'bm' => 'ಬಂಬಾರಾ',
        'bm_ML' => 'ಬಂಬಾರಾ (ಮಾಲಿ)',
        'bn' => 'ಬಾಂಗ್ಲಾ',
        'bn_BD' => 'ಬಾಂಗ್ಲಾ (ಬಾಂಗ್ಲಾದೇಶ)',
        'bn_IN' => 'ಬಾಂಗ್ಲಾ (ಭಾರತ)',
        'bo' => 'ಟಿಬೇಟಿಯನ್',
        'bo_CN' => 'ಟಿಬೇಟಿಯನ್ (ಚೀನಾ)',
        'bo_IN' => 'ಟಿಬೇಟಿಯನ್ (ಭಾರತ)',
        'br' => 'ಬ್ರೆಟನ್',
        'br_FR' => 'ಬ್ರೆಟನ್ (ಫ್ರಾನ್ಸ್)',
        'bs' => 'ಬೋಸ್ನಿಯನ್',
        'bs_BA' => 'ಬೋಸ್ನಿಯನ್ (ಬೋಸ್ನಿಯಾ ಮತ್ತು ಹರ್ಜೆಗೋವಿನಾ)',
        'bs_Cyrl' => 'ಬೋಸ್ನಿಯನ್ (ಸಿರಿಲಿಕ್)',
        'bs_Cyrl_BA' => 'ಬೋಸ್ನಿಯನ್ (ಸಿರಿಲಿಕ್, ಬೋಸ್ನಿಯಾ ಮತ್ತು ಹರ್ಜೆಗೋವಿನಾ)',
        'bs_Latn' => 'ಬೋಸ್ನಿಯನ್ (ಲ್ಯಾಟಿನ್)',
        'bs_Latn_BA' => 'ಬೋಸ್ನಿಯನ್ (ಲ್ಯಾಟಿನ್, ಬೋಸ್ನಿಯಾ ಮತ್ತು ಹರ್ಜೆಗೋವಿನಾ)',
        'ca' => 'ಕೆಟಲಾನ್',
        'ca_AD' => 'ಕೆಟಲಾನ್ (ಅಂಡೋರಾ)',
        'ca_ES' => 'ಕೆಟಲಾನ್ (ಸ್ಪೇನ್)',
        'ca_FR' => 'ಕೆಟಲಾನ್ (ಫ್ರಾನ್ಸ್)',
        'ca_IT' => 'ಕೆಟಲಾನ್ (ಇಟಲಿ)',
        'ce' => 'ಚಚೆನ್',
        'ce_RU' => 'ಚಚೆನ್ (ರಷ್ಯಾ)',
        'cs' => 'ಜೆಕ್',
        'cs_CZ' => 'ಜೆಕ್ (ಝೆಕಿಯಾ)',
        'cv' => 'ಚುವಾಶ್',
        'cv_RU' => 'ಚುವಾಶ್ (ರಷ್ಯಾ)',
        'cy' => 'ವೆಲ್ಶ್',
        'cy_GB' => 'ವೆಲ್ಶ್ (ಯುನೈಟೆಡ್ ಕಿಂಗ್‌ಡಮ್)',
        'da' => 'ಡ್ಯಾನಿಶ್',
        'da_DK' => 'ಡ್ಯಾನಿಶ್ (ಡೆನ್ಮಾರ್ಕ್)',
        'da_GL' => 'ಡ್ಯಾನಿಶ್ (ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್)',
        'de' => 'ಜರ್ಮನ್',
        'de_AT' => 'ಜರ್ಮನ್ (ಆಸ್ಟ್ರಿಯಾ)',
        'de_BE' => 'ಜರ್ಮನ್ (ಬೆಲ್ಜಿಯಮ್)',
        'de_CH' => 'ಜರ್ಮನ್ (ಸ್ವಿಟ್ಜರ್ಲ್ಯಾಂಡ್)',
        'de_DE' => 'ಜರ್ಮನ್ (ಜರ್ಮನಿ)',
        'de_IT' => 'ಜರ್ಮನ್ (ಇಟಲಿ)',
        'de_LI' => 'ಜರ್ಮನ್ (ಲಿಚೆನ್‌ಸ್ಟೈನ್)',
        'de_LU' => 'ಜರ್ಮನ್ (ಲಕ್ಸೆಂಬರ್ಗ್)',
        'dz' => 'ಜೋಂಗ್‌ಖಾ',
        'dz_BT' => 'ಜೋಂಗ್‌ಖಾ (ಭೂತಾನ್)',
        'ee' => 'ಈವ್',
        'ee_GH' => 'ಈವ್ (ಘಾನಾ)',
        'ee_TG' => 'ಈವ್ (ಟೋಗೋ)',
        'el' => 'ಗ್ರೀಕ್',
        'el_CY' => 'ಗ್ರೀಕ್ (ಸೈಪ್ರಸ್)',
        'el_GR' => 'ಗ್ರೀಕ್ (ಗ್ರೀಸ್)',
        'en' => 'ಇಂಗ್ಲಿಷ್',
        'en_001' => 'ಇಂಗ್ಲಿಷ್ (ಪ್ರಪಂಚ)',
        'en_150' => 'ಇಂಗ್ಲಿಷ್ (ಯೂರೋಪ್)',
        'en_AE' => 'ಇಂಗ್ಲಿಷ್ (ಯುನೈಟೆಡ್ ಅರಬ್ ಎಮಿರೇಟ್ಸ್)',
        'en_AG' => 'ಇಂಗ್ಲಿಷ್ (ಆಂಟಿಗುವಾ ಮತ್ತು ಬರ್ಬುಡಾ)',
        'en_AI' => 'ಇಂಗ್ಲಿಷ್ (ಆಂಗ್ವಿಲ್ಲಾ)',
        'en_AS' => 'ಇಂಗ್ಲಿಷ್ (ಅಮೇರಿಕನ್ ಸಮೋವಾ)',
        'en_AT' => 'ಇಂಗ್ಲಿಷ್ (ಆಸ್ಟ್ರಿಯಾ)',
        'en_AU' => 'ಇಂಗ್ಲಿಷ್ (ಆಸ್ಟ್ರೇಲಿಯಾ)',
        'en_BB' => 'ಇಂಗ್ಲಿಷ್ (ಬಾರ್ಬಡೋಸ್)',
        'en_BE' => 'ಇಂಗ್ಲಿಷ್ (ಬೆಲ್ಜಿಯಮ್)',
        'en_BI' => 'ಇಂಗ್ಲಿಷ್ (ಬುರುಂಡಿ)',
        'en_BM' => 'ಇಂಗ್ಲಿಷ್ (ಬರ್ಮುಡಾ)',
        'en_BS' => 'ಇಂಗ್ಲಿಷ್ (ಬಹಾಮಾಸ್)',
        'en_BW' => 'ಇಂಗ್ಲಿಷ್ (ಬೋಟ್ಸ್‌ವಾನಾ)',
        'en_BZ' => 'ಇಂಗ್ಲಿಷ್ (ಬೆಲಿಜ್)',
        'en_CA' => 'ಇಂಗ್ಲಿಷ್ (ಕೆನಡಾ)',
        'en_CC' => 'ಇಂಗ್ಲಿಷ್ (ಕೊಕೊಸ್ [ಕೀಲಿಂಗ್] ದ್ವೀಪಗಳು)',
        'en_CH' => 'ಇಂಗ್ಲಿಷ್ (ಸ್ವಿಟ್ಜರ್ಲ್ಯಾಂಡ್)',
        'en_CK' => 'ಇಂಗ್ಲಿಷ್ (ಕುಕ್ ದ್ವೀಪಗಳು)',
        'en_CM' => 'ಇಂಗ್ಲಿಷ್ (ಕ್ಯಾಮರೂನ್)',
        'en_CX' => 'ಇಂಗ್ಲಿಷ್ (ಕ್ರಿಸ್ಮಸ್ ದ್ವೀಪ)',
        'en_CY' => 'ಇಂಗ್ಲಿಷ್ (ಸೈಪ್ರಸ್)',
        'en_DE' => 'ಇಂಗ್ಲಿಷ್ (ಜರ್ಮನಿ)',
        'en_DK' => 'ಇಂಗ್ಲಿಷ್ (ಡೆನ್ಮಾರ್ಕ್)',
        'en_DM' => 'ಇಂಗ್ಲಿಷ್ (ಡೊಮಿನಿಕಾ)',
        'en_ER' => 'ಇಂಗ್ಲಿಷ್ (ಎರಿಟ್ರಿಯಾ)',
        'en_FI' => 'ಇಂಗ್ಲಿಷ್ (ಫಿನ್‌ಲ್ಯಾಂಡ್)',
        'en_FJ' => 'ಇಂಗ್ಲಿಷ್ (ಫಿಜಿ)',
        'en_FK' => 'ಇಂಗ್ಲಿಷ್ (ಫಾಕ್‌ಲ್ಯಾಂಡ್ ದ್ವೀಪಗಳು)',
        'en_FM' => 'ಇಂಗ್ಲಿಷ್ (ಮೈಕ್ರೋನೇಶಿಯಾ)',
        'en_GB' => 'ಇಂಗ್ಲಿಷ್ (ಯುನೈಟೆಡ್ ಕಿಂಗ್‌ಡಮ್)',
        'en_GD' => 'ಇಂಗ್ಲಿಷ್ (ಗ್ರೆನೆಡಾ)',
        'en_GG' => 'ಇಂಗ್ಲಿಷ್ (ಗುರ್ನ್‌ಸೆ)',
        'en_GH' => 'ಇಂಗ್ಲಿಷ್ (ಘಾನಾ)',
        'en_GI' => 'ಇಂಗ್ಲಿಷ್ (ಗಿಬ್ರಾಲ್ಟರ್)',
        'en_GM' => 'ಇಂಗ್ಲಿಷ್ (ಗ್ಯಾಂಬಿಯಾ)',
        'en_GU' => 'ಇಂಗ್ಲಿಷ್ (ಗುವಾಮ್)',
        'en_GY' => 'ಇಂಗ್ಲಿಷ್ (ಗಯಾನಾ)',
        'en_HK' => 'ಇಂಗ್ಲಿಷ್ (ಹಾಂಗ್ ಕಾಂಗ್ SAR ಚೈನಾ)',
        'en_IE' => 'ಇಂಗ್ಲಿಷ್ (ಐರ್ಲೆಂಡ್)',
        'en_IL' => 'ಇಂಗ್ಲಿಷ್ (ಇಸ್ರೇಲ್)',
        'en_IM' => 'ಇಂಗ್ಲಿಷ್ (ಐಲ್ ಆಫ್ ಮ್ಯಾನ್)',
        'en_IN' => 'ಇಂಗ್ಲಿಷ್ (ಭಾರತ)',
        'en_IO' => 'ಇಂಗ್ಲಿಷ್ (ಬ್ರಿಟೀಷ್ ಹಿಂದೂ ಮಹಾಸಾಗರದ ಪ್ರದೇಶ)',
        'en_JE' => 'ಇಂಗ್ಲಿಷ್ (ಜೆರ್ಸಿ)',
        'en_JM' => 'ಇಂಗ್ಲಿಷ್ (ಜಮೈಕಾ)',
        'en_KE' => 'ಇಂಗ್ಲಿಷ್ (ಕೀನ್ಯಾ)',
        'en_KI' => 'ಇಂಗ್ಲಿಷ್ (ಕಿರಿಬಾಟಿ)',
        'en_KN' => 'ಇಂಗ್ಲಿಷ್ (ಸೇಂಟ್ ಕಿಟ್ಸ್ ಮತ್ತು ನೆವಿಸ್)',
        'en_KY' => 'ಇಂಗ್ಲಿಷ್ (ಕೇಮನ್ ದ್ವೀಪಗಳು)',
        'en_LC' => 'ಇಂಗ್ಲಿಷ್ (ಸೇಂಟ್ ಲೂಸಿಯಾ)',
        'en_LR' => 'ಇಂಗ್ಲಿಷ್ (ಲಿಬೇರಿಯಾ)',
        'en_LS' => 'ಇಂಗ್ಲಿಷ್ (ಲೆಸೊಥೊ)',
        'en_MG' => 'ಇಂಗ್ಲಿಷ್ (ಮಡಗಾಸ್ಕರ್)',
        'en_MH' => 'ಇಂಗ್ಲಿಷ್ (ಮಾರ್ಷಲ್ ದ್ವೀಪಗಳು)',
        'en_MO' => 'ಇಂಗ್ಲಿಷ್ (ಮಕಾವು SAR ಚೈನಾ)',
        'en_MP' => 'ಇಂಗ್ಲಿಷ್ (ಉತ್ತರ ಮರಿಯಾನಾ ದ್ವೀಪಗಳು)',
        'en_MS' => 'ಇಂಗ್ಲಿಷ್ (ಮಾಂಟ್‌ಸೆರಟ್)',
        'en_MT' => 'ಇಂಗ್ಲಿಷ್ (ಮಾಲ್ಟಾ)',
        'en_MU' => 'ಇಂಗ್ಲಿಷ್ (ಮಾರಿಷಸ್)',
        'en_MV' => 'ಇಂಗ್ಲಿಷ್ (ಮಾಲ್ಡೀವ್ಸ್)',
        'en_MW' => 'ಇಂಗ್ಲಿಷ್ (ಮಲಾವಿ)',
        'en_MY' => 'ಇಂಗ್ಲಿಷ್ (ಮಲೇಶಿಯಾ)',
        'en_NA' => 'ಇಂಗ್ಲಿಷ್ (ನಮೀಬಿಯಾ)',
        'en_NF' => 'ಇಂಗ್ಲಿಷ್ (ನಾರ್ಫೋಕ್ ದ್ವೀಪ)',
        'en_NG' => 'ಇಂಗ್ಲಿಷ್ (ನೈಜೀರಿಯಾ)',
        'en_NL' => 'ಇಂಗ್ಲಿಷ್ (ನೆದರ್‌ಲ್ಯಾಂಡ್ಸ್)',
        'en_NR' => 'ಇಂಗ್ಲಿಷ್ (ನೌರು)',
        'en_NU' => 'ಇಂಗ್ಲಿಷ್ (ನಿಯು)',
        'en_NZ' => 'ಇಂಗ್ಲಿಷ್ (ನ್ಯೂಜಿಲೆಂಡ್)',
        'en_PG' => 'ಇಂಗ್ಲಿಷ್ (ಪಪುವಾ ನ್ಯೂಗಿನಿಯಾ)',
        'en_PH' => 'ಇಂಗ್ಲಿಷ್ (ಫಿಲಿಫೈನ್ಸ್)',
        'en_PK' => 'ಇಂಗ್ಲಿಷ್ (ಪಾಕಿಸ್ತಾನ)',
        'en_PN' => 'ಇಂಗ್ಲಿಷ್ (ಪಿಟ್‌ಕೈರ್ನ್ ದ್ವೀಪಗಳು)',
        'en_PR' => 'ಇಂಗ್ಲಿಷ್ (ಪ್ಯೂರ್ಟೋ ರಿಕೊ)',
        'en_PW' => 'ಇಂಗ್ಲಿಷ್ (ಪಲಾವು)',
        'en_RW' => 'ಇಂಗ್ಲಿಷ್ (ರುವಾಂಡಾ)',
        'en_SB' => 'ಇಂಗ್ಲಿಷ್ (ಸಾಲೊಮನ್ ದ್ವೀಪಗಳು)',
        'en_SC' => 'ಇಂಗ್ಲಿಷ್ (ಸೀಶೆಲ್ಲೆಸ್)',
        'en_SD' => 'ಇಂಗ್ಲಿಷ್ (ಸುಡಾನ್)',
        'en_SE' => 'ಇಂಗ್ಲಿಷ್ (ಸ್ವೀಡನ್)',
        'en_SG' => 'ಇಂಗ್ಲಿಷ್ (ಸಿಂಗಪುರ್)',
        'en_SH' => 'ಇಂಗ್ಲಿಷ್ (ಸೇಂಟ್ ಹೆಲೆನಾ)',
        'en_SI' => 'ಇಂಗ್ಲಿಷ್ (ಸ್ಲೋವೇನಿಯಾ)',
        'en_SL' => 'ಇಂಗ್ಲಿಷ್ (ಸಿಯೆರ್ರಾ ಲಿಯೋನ್)',
        'en_SS' => 'ಇಂಗ್ಲಿಷ್ (ದಕ್ಷಿಣ ಸುಡಾನ್)',
        'en_SX' => 'ಇಂಗ್ಲಿಷ್ (ಸಿಂಟ್ ಮಾರ್ಟೆನ್)',
        'en_SZ' => 'ಇಂಗ್ಲಿಷ್ (ಎಸ್ವಾಟಿನಿ)',
        'en_TC' => 'ಇಂಗ್ಲಿಷ್ (ಟರ್ಕ್ಸ್ ಮತ್ತು ಕೈಕೋಸ್ ದ್ವೀಪಗಳು)',
        'en_TK' => 'ಇಂಗ್ಲಿಷ್ (ಟೊಕೆಲಾವ್)',
        'en_TO' => 'ಇಂಗ್ಲಿಷ್ (ಟೊಂಗಾ)',
        'en_TT' => 'ಇಂಗ್ಲಿಷ್ (ಟ್ರಿನಿಡಾಡ್ ಮತ್ತು ಟೊಬಾಗೊ)',
        'en_TV' => 'ಇಂಗ್ಲಿಷ್ (ಟುವಾಲು)',
        'en_TZ' => 'ಇಂಗ್ಲಿಷ್ (ತಾಂಜೇನಿಯಾ)',
        'en_UG' => 'ಇಂಗ್ಲಿಷ್ (ಉಗಾಂಡಾ)',
        'en_UM' => 'ಇಂಗ್ಲಿಷ್ (ಯುಎಸ್‌ ಔಟ್‌ಲೇಯಿಂಗ್ ದ್ವೀಪಗಳು)',
        'en_US' => 'ಇಂಗ್ಲಿಷ್ (ಯುನೈಟೆಡ್ ಸ್ಟೇಟ್ಸ್)',
        'en_VC' => 'ಇಂಗ್ಲಿಷ್ (ಸೇಂಟ್. ವಿನ್ಸೆಂಟ್ ಮತ್ತು ಗ್ರೆನೆಡೈನ್ಸ್)',
        'en_VG' => 'ಇಂಗ್ಲಿಷ್ (ಬ್ರಿಟಿಷ್ ವರ್ಜಿನ್ ದ್ವೀಪಗಳು)',
        'en_VI' => 'ಇಂಗ್ಲಿಷ್ (ಯು.ಎಸ್. ವರ್ಜಿನ್ ದ್ವೀಪಗಳು)',
        'en_VU' => 'ಇಂಗ್ಲಿಷ್ (ವನೌಟು)',
        'en_WS' => 'ಇಂಗ್ಲಿಷ್ (ಸಮೋವಾ)',
        'en_ZA' => 'ಇಂಗ್ಲಿಷ್ (ದಕ್ಷಿಣ ಆಫ್ರಿಕಾ)',
        'en_ZM' => 'ಇಂಗ್ಲಿಷ್ (ಜಾಂಬಿಯ)',
        'en_ZW' => 'ಇಂಗ್ಲಿಷ್ (ಜಿಂಬಾಬ್ವೆ)',
        'eo' => 'ಎಸ್ಪೆರಾಂಟೊ',
        'eo_001' => 'ಎಸ್ಪೆರಾಂಟೊ (ಪ್ರಪಂಚ)',
        'es' => 'ಸ್ಪ್ಯಾನಿಷ್',
        'es_419' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಲ್ಯಾಟಿನ್ ಅಮೇರಿಕಾ)',
        'es_AR' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಅರ್ಜೆಂಟಿನಾ)',
        'es_BO' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಬೊಲಿವಿಯಾ)',
        'es_BR' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಬ್ರೆಜಿಲ್)',
        'es_BZ' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಬೆಲಿಜ್)',
        'es_CL' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಚಿಲಿ)',
        'es_CO' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಕೊಲಂಬಿಯಾ)',
        'es_CR' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಕೊಸ್ಟಾ ರಿಕಾ)',
        'es_CU' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಕ್ಯೂಬಾ)',
        'es_DO' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಡೊಮೆನಿಕನ್ ರಿಪಬ್ಲಿಕ್)',
        'es_EC' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಈಕ್ವೆಡಾರ್)',
        'es_ES' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಸ್ಪೇನ್)',
        'es_GQ' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಈಕ್ವೆಟೋರಿಯಲ್ ಗಿನಿ)',
        'es_GT' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಗ್ವಾಟೆಮಾಲಾ)',
        'es_HN' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಹೊಂಡುರಾಸ್)',
        'es_MX' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಮೆಕ್ಸಿಕೊ)',
        'es_NI' => 'ಸ್ಪ್ಯಾನಿಷ್ (ನಿಕಾರಾಗುವಾ)',
        'es_PA' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಪನಾಮಾ)',
        'es_PE' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಪೆರು)',
        'es_PH' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಫಿಲಿಫೈನ್ಸ್)',
        'es_PR' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಪ್ಯೂರ್ಟೋ ರಿಕೊ)',
        'es_PY' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಪರಾಗ್ವೇ)',
        'es_SV' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಎಲ್ ಸಾಲ್ವೇಡಾರ್)',
        'es_US' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಯುನೈಟೆಡ್ ಸ್ಟೇಟ್ಸ್)',
        'es_UY' => 'ಸ್ಪ್ಯಾನಿಷ್ (ಉರುಗ್ವೆ)',
        'es_VE' => 'ಸ್ಪ್ಯಾನಿಷ್ (ವೆನೆಜುವೆಲಾ)',
        'et' => 'ಎಸ್ಟೊನಿಯನ್',
        'et_EE' => 'ಎಸ್ಟೊನಿಯನ್ (ಎಸ್ಟೋನಿಯಾ)',
        'eu' => 'ಬಾಸ್ಕ್',
        'eu_ES' => 'ಬಾಸ್ಕ್ (ಸ್ಪೇನ್)',
        'fa' => 'ಪರ್ಶಿಯನ್',
        'fa_AF' => 'ಪರ್ಶಿಯನ್ (ಅಫಘಾನಿಸ್ಥಾನ)',
        'fa_IR' => 'ಪರ್ಶಿಯನ್ (ಇರಾನ್)',
        'ff' => 'ಫುಲಾ',
        'ff_Adlm' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್)',
        'ff_Adlm_BF' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಬುರ್ಕಿನಾ ಫಾಸೊ)',
        'ff_Adlm_CM' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಕ್ಯಾಮರೂನ್)',
        'ff_Adlm_GH' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಘಾನಾ)',
        'ff_Adlm_GM' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಗ್ಯಾಂಬಿಯಾ)',
        'ff_Adlm_GN' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಗಿನಿ)',
        'ff_Adlm_GW' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಗಿನಿ-ಬಿಸ್ಸಾವ್)',
        'ff_Adlm_LR' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಲಿಬೇರಿಯಾ)',
        'ff_Adlm_MR' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಮಾರಿಟೇನಿಯಾ)',
        'ff_Adlm_NE' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ನೈಜರ್)',
        'ff_Adlm_NG' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ನೈಜೀರಿಯಾ)',
        'ff_Adlm_SL' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಸಿಯೆರ್ರಾ ಲಿಯೋನ್)',
        'ff_Adlm_SN' => 'ಫುಲಾ (ಆ್ಯಡ್ಲಮ್, ಸೆನೆಗಲ್)',
        'ff_CM' => 'ಫುಲಾ (ಕ್ಯಾಮರೂನ್)',
        'ff_GN' => 'ಫುಲಾ (ಗಿನಿ)',
        'ff_Latn' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್)',
        'ff_Latn_BF' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್, ಬುರ್ಕಿನಾ ಫಾಸೊ)',
        'ff_Latn_CM' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್, ಕ್ಯಾಮರೂನ್)',
        'ff_Latn_GH' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್, ಘಾನಾ)',
        'ff_Latn_GM' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್, ಗ್ಯಾಂಬಿಯಾ)',
        'ff_Latn_GN' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್, ಗಿನಿ)',
        'ff_Latn_GW' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್, ಗಿನಿ-ಬಿಸ್ಸಾವ್)',
        'ff_Latn_LR' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್, ಲಿಬೇರಿಯಾ)',
        'ff_Latn_MR' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್, ಮಾರಿಟೇನಿಯಾ)',
        'ff_Latn_NE' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್, ನೈಜರ್)',
        'ff_Latn_NG' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್, ನೈಜೀರಿಯಾ)',
        'ff_Latn_SL' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್, ಸಿಯೆರ್ರಾ ಲಿಯೋನ್)',
        'ff_Latn_SN' => 'ಫುಲಾ (ಲ್ಯಾಟಿನ್, ಸೆನೆಗಲ್)',
        'ff_MR' => 'ಫುಲಾ (ಮಾರಿಟೇನಿಯಾ)',
        'ff_SN' => 'ಫುಲಾ (ಸೆನೆಗಲ್)',
        'fi' => 'ಫಿನ್ನಿಶ್',
        'fi_FI' => 'ಫಿನ್ನಿಶ್ (ಫಿನ್‌ಲ್ಯಾಂಡ್)',
        'fo' => 'ಫರೋಸಿ',
        'fo_DK' => 'ಫರೋಸಿ (ಡೆನ್ಮಾರ್ಕ್)',
        'fo_FO' => 'ಫರೋಸಿ (ಫರೋ ದ್ವೀಪಗಳು)',
        'fr' => 'ಫ್ರೆಂಚ್',
        'fr_BE' => 'ಫ್ರೆಂಚ್ (ಬೆಲ್ಜಿಯಮ್)',
        'fr_BF' => 'ಫ್ರೆಂಚ್ (ಬುರ್ಕಿನಾ ಫಾಸೊ)',
        'fr_BI' => 'ಫ್ರೆಂಚ್ (ಬುರುಂಡಿ)',
        'fr_BJ' => 'ಫ್ರೆಂಚ್ (ಬೆನಿನ್)',
        'fr_BL' => 'ಫ್ರೆಂಚ್ (ಸೇಂಟ್ ಬಾರ್ಥೆಲೆಮಿ)',
        'fr_CA' => 'ಫ್ರೆಂಚ್ (ಕೆನಡಾ)',
        'fr_CD' => 'ಫ್ರೆಂಚ್ (ಕಾಂಗೋ - ಕಿನ್ಶಾಸಾ)',
        'fr_CF' => 'ಫ್ರೆಂಚ್ (ಮಧ್ಯ ಆಫ್ರಿಕಾ ಗಣರಾಜ್ಯ)',
        'fr_CG' => 'ಫ್ರೆಂಚ್ (ಕಾಂಗೋ - ಬ್ರಾಜಾವಿಲ್ಲೇ)',
        'fr_CH' => 'ಫ್ರೆಂಚ್ (ಸ್ವಿಟ್ಜರ್ಲ್ಯಾಂಡ್)',
        'fr_CI' => 'ಫ್ರೆಂಚ್ (ಕೋತ್ ದ್‘ಇವಾರ್)',
        'fr_CM' => 'ಫ್ರೆಂಚ್ (ಕ್ಯಾಮರೂನ್)',
        'fr_DJ' => 'ಫ್ರೆಂಚ್ (ಜಿಬೂಟಿ)',
        'fr_DZ' => 'ಫ್ರೆಂಚ್ (ಅಲ್ಜೀರಿಯ)',
        'fr_FR' => 'ಫ್ರೆಂಚ್ (ಫ್ರಾನ್ಸ್)',
        'fr_GA' => 'ಫ್ರೆಂಚ್ (ಗೆಬೊನ್)',
        'fr_GF' => 'ಫ್ರೆಂಚ್ (ಫ್ರೆಂಚ್ ಗಯಾನಾ)',
        'fr_GN' => 'ಫ್ರೆಂಚ್ (ಗಿನಿ)',
        'fr_GP' => 'ಫ್ರೆಂಚ್ (ಗುಡೆಲೋಪ್)',
        'fr_GQ' => 'ಫ್ರೆಂಚ್ (ಈಕ್ವೆಟೋರಿಯಲ್ ಗಿನಿ)',
        'fr_HT' => 'ಫ್ರೆಂಚ್ (ಹೈಟಿ)',
        'fr_KM' => 'ಫ್ರೆಂಚ್ (ಕೊಮೊರೊಸ್)',
        'fr_LU' => 'ಫ್ರೆಂಚ್ (ಲಕ್ಸೆಂಬರ್ಗ್)',
        'fr_MA' => 'ಫ್ರೆಂಚ್ (ಮೊರಾಕ್ಕೊ)',
        'fr_MC' => 'ಫ್ರೆಂಚ್ (ಮೊನಾಕೊ)',
        'fr_MF' => 'ಫ್ರೆಂಚ್ (ಸೇಂಟ್ ಮಾರ್ಟಿನ್)',
        'fr_MG' => 'ಫ್ರೆಂಚ್ (ಮಡಗಾಸ್ಕರ್)',
        'fr_ML' => 'ಫ್ರೆಂಚ್ (ಮಾಲಿ)',
        'fr_MQ' => 'ಫ್ರೆಂಚ್ (ಮಾರ್ಟಿನಿಕ್)',
        'fr_MR' => 'ಫ್ರೆಂಚ್ (ಮಾರಿಟೇನಿಯಾ)',
        'fr_MU' => 'ಫ್ರೆಂಚ್ (ಮಾರಿಷಸ್)',
        'fr_NC' => 'ಫ್ರೆಂಚ್ (ನ್ಯೂ ಕ್ಯಾಲಿಡೋನಿಯಾ)',
        'fr_NE' => 'ಫ್ರೆಂಚ್ (ನೈಜರ್)',
        'fr_PF' => 'ಫ್ರೆಂಚ್ (ಫ್ರೆಂಚ್ ಪಾಲಿನೇಷ್ಯಾ)',
        'fr_PM' => 'ಫ್ರೆಂಚ್ (ಸೇಂಟ್ ಪಿಯರ್ ಮತ್ತು ಮಿಕ್ವೆಲನ್)',
        'fr_RE' => 'ಫ್ರೆಂಚ್ (ರಿಯೂನಿಯನ್)',
        'fr_RW' => 'ಫ್ರೆಂಚ್ (ರುವಾಂಡಾ)',
        'fr_SC' => 'ಫ್ರೆಂಚ್ (ಸೀಶೆಲ್ಲೆಸ್)',
        'fr_SN' => 'ಫ್ರೆಂಚ್ (ಸೆನೆಗಲ್)',
        'fr_SY' => 'ಫ್ರೆಂಚ್ (ಸಿರಿಯಾ)',
        'fr_TD' => 'ಫ್ರೆಂಚ್ (ಚಾದ್)',
        'fr_TG' => 'ಫ್ರೆಂಚ್ (ಟೋಗೋ)',
        'fr_TN' => 'ಫ್ರೆಂಚ್ (ಟುನೀಶಿಯ)',
        'fr_VU' => 'ಫ್ರೆಂಚ್ (ವನೌಟು)',
        'fr_WF' => 'ಫ್ರೆಂಚ್ (ವಾಲಿಸ್ ಮತ್ತು ಫುಟುನಾ)',
        'fr_YT' => 'ಫ್ರೆಂಚ್ (ಮಯೊಟ್ಟೆ)',
        'fy' => 'ಪಶ್ಚಿಮ ಫ್ರಿಸಿಯನ್',
        'fy_NL' => 'ಪಶ್ಚಿಮ ಫ್ರಿಸಿಯನ್ (ನೆದರ್‌ಲ್ಯಾಂಡ್ಸ್)',
        'ga' => 'ಐರಿಷ್',
        'ga_GB' => 'ಐರಿಷ್ (ಯುನೈಟೆಡ್ ಕಿಂಗ್‌ಡಮ್)',
        'ga_IE' => 'ಐರಿಷ್ (ಐರ್ಲೆಂಡ್)',
        'gd' => 'ಸ್ಕಾಟಿಶ್ ಗೆಲಿಕ್',
        'gd_GB' => 'ಸ್ಕಾಟಿಶ್ ಗೆಲಿಕ್ (ಯುನೈಟೆಡ್ ಕಿಂಗ್‌ಡಮ್)',
        'gl' => 'ಗ್ಯಾಲಿಶಿಯನ್',
        'gl_ES' => 'ಗ್ಯಾಲಿಶಿಯನ್ (ಸ್ಪೇನ್)',
        'gu' => 'ಗುಜರಾತಿ',
        'gu_IN' => 'ಗುಜರಾತಿ (ಭಾರತ)',
        'gv' => 'ಮ್ಯಾಂಕ್ಸ್',
        'gv_IM' => 'ಮ್ಯಾಂಕ್ಸ್ (ಐಲ್ ಆಫ್ ಮ್ಯಾನ್)',
        'ha' => 'ಹೌಸಾ',
        'ha_GH' => 'ಹೌಸಾ (ಘಾನಾ)',
        'ha_NE' => 'ಹೌಸಾ (ನೈಜರ್)',
        'ha_NG' => 'ಹೌಸಾ (ನೈಜೀರಿಯಾ)',
        'he' => 'ಹೀಬ್ರೂ',
        'he_IL' => 'ಹೀಬ್ರೂ (ಇಸ್ರೇಲ್)',
        'hi' => 'ಹಿಂದಿ',
        'hi_IN' => 'ಹಿಂದಿ (ಭಾರತ)',
        'hi_Latn' => 'ಹಿಂದಿ (ಲ್ಯಾಟಿನ್)',
        'hi_Latn_IN' => 'ಹಿಂದಿ (ಲ್ಯಾಟಿನ್, ಭಾರತ)',
        'hr' => 'ಕ್ರೊಯೇಶಿಯನ್',
        'hr_BA' => 'ಕ್ರೊಯೇಶಿಯನ್ (ಬೋಸ್ನಿಯಾ ಮತ್ತು ಹರ್ಜೆಗೋವಿನಾ)',
        'hr_HR' => 'ಕ್ರೊಯೇಶಿಯನ್ (ಕ್ರೊಯೇಷಿಯಾ)',
        'hu' => 'ಹಂಗೇರಿಯನ್',
        'hu_HU' => 'ಹಂಗೇರಿಯನ್ (ಹಂಗೇರಿ)',
        'hy' => 'ಅರ್ಮೇನಿಯನ್',
        'hy_AM' => 'ಅರ್ಮೇನಿಯನ್ (ಆರ್ಮೇನಿಯ)',
        'ia' => 'ಇಂಟರ್‌ಲಿಂಗ್ವಾ',
        'ia_001' => 'ಇಂಟರ್‌ಲಿಂಗ್ವಾ (ಪ್ರಪಂಚ)',
        'id' => 'ಇಂಡೋನೇಶಿಯನ್',
        'id_ID' => 'ಇಂಡೋನೇಶಿಯನ್ (ಇಂಡೋನೇಶಿಯಾ)',
        'ig' => 'ಇಗ್ಬೊ',
        'ig_NG' => 'ಇಗ್ಬೊ (ನೈಜೀರಿಯಾ)',
        'ii' => 'ಸಿಚುಅನ್ ಯಿ',
        'ii_CN' => 'ಸಿಚುಅನ್ ಯಿ (ಚೀನಾ)',
        'is' => 'ಐಸ್‌ಲ್ಯಾಂಡಿಕ್',
        'is_IS' => 'ಐಸ್‌ಲ್ಯಾಂಡಿಕ್ (ಐಸ್‌ಲ್ಯಾಂಡ್)',
        'it' => 'ಇಟಾಲಿಯನ್',
        'it_CH' => 'ಇಟಾಲಿಯನ್ (ಸ್ವಿಟ್ಜರ್ಲ್ಯಾಂಡ್)',
        'it_IT' => 'ಇಟಾಲಿಯನ್ (ಇಟಲಿ)',
        'it_SM' => 'ಇಟಾಲಿಯನ್ (ಸ್ಯಾನ್ ಮೆರಿನೋ)',
        'it_VA' => 'ಇಟಾಲಿಯನ್ (ವ್ಯಾಟಿಕನ್ ಸಿಟಿ)',
        'ja' => 'ಜಾಪನೀಸ್',
        'ja_JP' => 'ಜಾಪನೀಸ್ (ಜಪಾನ್)',
        'jv' => 'ಜಾವಾನೀಸ್',
        'jv_ID' => 'ಜಾವಾನೀಸ್ (ಇಂಡೋನೇಶಿಯಾ)',
        'ka' => 'ಜಾರ್ಜಿಯನ್',
        'ka_GE' => 'ಜಾರ್ಜಿಯನ್ (ಜಾರ್ಜಿಯಾ)',
        'ki' => 'ಕಿಕುಯು',
        'ki_KE' => 'ಕಿಕುಯು (ಕೀನ್ಯಾ)',
        'kk' => 'ಕಝಕ್',
        'kk_KZ' => 'ಕಝಕ್ (ಕಝಾಕಿಸ್ಥಾನ್)',
        'kl' => 'ಕಲಾಲ್ಲಿಸುಟ್',
        'kl_GL' => 'ಕಲಾಲ್ಲಿಸುಟ್ (ಗ್ರೀನ್‌ಲ್ಯಾಂಡ್)',
        'km' => 'ಖಮೇರ್',
        'km_KH' => 'ಖಮೇರ್ (ಕಾಂಬೋಡಿಯಾ)',
        'kn' => 'ಕನ್ನಡ',
        'kn_IN' => 'ಕನ್ನಡ (ಭಾರತ)',
        'ko' => 'ಕೊರಿಯನ್',
        'ko_KP' => 'ಕೊರಿಯನ್ (ಉತ್ತರ ಕೊರಿಯಾ)',
        'ko_KR' => 'ಕೊರಿಯನ್ (ದಕ್ಷಿಣ ಕೊರಿಯಾ)',
        'ks' => 'ಕಾಶ್ಮೀರಿ',
        'ks_Arab' => 'ಕಾಶ್ಮೀರಿ (ಅರೇಬಿಕ್)',
        'ks_Arab_IN' => 'ಕಾಶ್ಮೀರಿ (ಅರೇಬಿಕ್, ಭಾರತ)',
        'ks_Deva' => 'ಕಾಶ್ಮೀರಿ (ದೇವನಾಗರಿ)',
        'ks_Deva_IN' => 'ಕಾಶ್ಮೀರಿ (ದೇವನಾಗರಿ, ಭಾರತ)',
        'ks_IN' => 'ಕಾಶ್ಮೀರಿ (ಭಾರತ)',
        'ku' => 'ಕುರ್ದಿಷ್',
        'ku_TR' => 'ಕುರ್ದಿಷ್ (ಟರ್ಕಿ)',
        'kw' => 'ಕಾರ್ನಿಷ್',
        'kw_GB' => 'ಕಾರ್ನಿಷ್ (ಯುನೈಟೆಡ್ ಕಿಂಗ್‌ಡಮ್)',
        'ky' => 'ಕಿರ್ಗಿಜ್',
        'ky_KG' => 'ಕಿರ್ಗಿಜ್ (ಕಿರ್ಗಿಸ್ಥಾನ್)',
        'lb' => 'ಲಕ್ಸಂಬರ್ಗಿಷ್',
        'lb_LU' => 'ಲಕ್ಸಂಬರ್ಗಿಷ್ (ಲಕ್ಸೆಂಬರ್ಗ್)',
        'lg' => 'ಗಾಂಡಾ',
        'lg_UG' => 'ಗಾಂಡಾ (ಉಗಾಂಡಾ)',
        'ln' => 'ಲಿಂಗಾಲ',
        'ln_AO' => 'ಲಿಂಗಾಲ (ಅಂಗೋಲಾ)',
        'ln_CD' => 'ಲಿಂಗಾಲ (ಕಾಂಗೋ - ಕಿನ್ಶಾಸಾ)',
        'ln_CF' => 'ಲಿಂಗಾಲ (ಮಧ್ಯ ಆಫ್ರಿಕಾ ಗಣರಾಜ್ಯ)',
        'ln_CG' => 'ಲಿಂಗಾಲ (ಕಾಂಗೋ - ಬ್ರಾಜಾವಿಲ್ಲೇ)',
        'lo' => 'ಲಾವೋ',
        'lo_LA' => 'ಲಾವೋ (ಲಾವೋಸ್)',
        'lt' => 'ಲಿಥುವೇನಿಯನ್',
        'lt_LT' => 'ಲಿಥುವೇನಿಯನ್ (ಲಿಥುವೇನಿಯಾ)',
        'lu' => 'ಲೂಬಾ-ಕಟಾಂಗಾ',
        'lu_CD' => 'ಲೂಬಾ-ಕಟಾಂಗಾ (ಕಾಂಗೋ - ಕಿನ್ಶಾಸಾ)',
        'lv' => 'ಲಾಟ್ವಿಯನ್',
        'lv_LV' => 'ಲಾಟ್ವಿಯನ್ (ಲಾಟ್ವಿಯಾ)',
        'mg' => 'ಮಲಗಾಸಿ',
        'mg_MG' => 'ಮಲಗಾಸಿ (ಮಡಗಾಸ್ಕರ್)',
        'mi' => 'ಮಾವೋರಿ',
        'mi_NZ' => 'ಮಾವೋರಿ (ನ್ಯೂಜಿಲೆಂಡ್)',
        'mk' => 'ಮೆಸಿಡೋನಿಯನ್',
        'mk_MK' => 'ಮೆಸಿಡೋನಿಯನ್ (ಉತ್ತರ ಮ್ಯಾಸಿಡೋನಿಯಾ)',
        'ml' => 'ಮಲಯಾಳಂ',
        'ml_IN' => 'ಮಲಯಾಳಂ (ಭಾರತ)',
        'mn' => 'ಮಂಗೋಲಿಯನ್',
        'mn_MN' => 'ಮಂಗೋಲಿಯನ್ (ಮಂಗೋಲಿಯಾ)',
        'mr' => 'ಮರಾಠಿ',
        'mr_IN' => 'ಮರಾಠಿ (ಭಾರತ)',
        'ms' => 'ಮಲಯ್',
        'ms_BN' => 'ಮಲಯ್ (ಬ್ರೂನಿ)',
        'ms_ID' => 'ಮಲಯ್ (ಇಂಡೋನೇಶಿಯಾ)',
        'ms_MY' => 'ಮಲಯ್ (ಮಲೇಶಿಯಾ)',
        'ms_SG' => 'ಮಲಯ್ (ಸಿಂಗಪುರ್)',
        'mt' => 'ಮಾಲ್ಟೀಸ್',
        'mt_MT' => 'ಮಾಲ್ಟೀಸ್ (ಮಾಲ್ಟಾ)',
        'my' => 'ಬರ್ಮೀಸ್',
        'my_MM' => 'ಬರ್ಮೀಸ್ (ಮಯನ್ಮಾರ್ [ಬರ್ಮಾ])',
        'nb' => 'ನಾರ್ವೆಜಿಯನ್ ಬೊಕ್ಮಲ್',
        'nb_NO' => 'ನಾರ್ವೆಜಿಯನ್ ಬೊಕ್ಮಲ್ (ನಾರ್ವೆ)',
        'nb_SJ' => 'ನಾರ್ವೆಜಿಯನ್ ಬೊಕ್ಮಲ್ (ಸ್ವಾಲ್ಬಾರ್ಡ್ ಮತ್ತು ಜಾನ್ ಮೆಯನ್)',
        'nd' => 'ಉತ್ತರ ದೆಬೆಲೆ',
        'nd_ZW' => 'ಉತ್ತರ ದೆಬೆಲೆ (ಜಿಂಬಾಬ್ವೆ)',
        'ne' => 'ನೇಪಾಳಿ',
        'ne_IN' => 'ನೇಪಾಳಿ (ಭಾರತ)',
        'ne_NP' => 'ನೇಪಾಳಿ (ನೇಪಾಳ)',
        'nl' => 'ಡಚ್',
        'nl_AW' => 'ಡಚ್ (ಅರುಬಾ)',
        'nl_BE' => 'ಡಚ್ (ಬೆಲ್ಜಿಯಮ್)',
        'nl_BQ' => 'ಡಚ್ (ಕೆರೀಬಿಯನ್ ನೆದರ್‌ಲ್ಯಾಂಡ್ಸ್)',
        'nl_CW' => 'ಡಚ್ (ಕುರಾಕಾವ್)',
        'nl_NL' => 'ಡಚ್ (ನೆದರ್‌ಲ್ಯಾಂಡ್ಸ್)',
        'nl_SR' => 'ಡಚ್ (ಸುರಿನಾಮ್)',
        'nl_SX' => 'ಡಚ್ (ಸಿಂಟ್ ಮಾರ್ಟೆನ್)',
        'nn' => 'ನಾರ್ವೇಜಿಯನ್ ನೈನಾರ್ಸ್ಕ್',
        'nn_NO' => 'ನಾರ್ವೇಜಿಯನ್ ನೈನಾರ್ಸ್ಕ್ (ನಾರ್ವೆ)',
        'no' => 'ನಾರ್ವೇಜಿಯನ್',
        'no_NO' => 'ನಾರ್ವೇಜಿಯನ್ (ನಾರ್ವೆ)',
        'om' => 'ಒರೊಮೊ',
        'om_ET' => 'ಒರೊಮೊ (ಇಥಿಯೋಪಿಯಾ)',
        'om_KE' => 'ಒರೊಮೊ (ಕೀನ್ಯಾ)',
        'or' => 'ಒಡಿಯ',
        'or_IN' => 'ಒಡಿಯ (ಭಾರತ)',
        'os' => 'ಒಸ್ಸೆಟಿಕ್',
        'os_GE' => 'ಒಸ್ಸೆಟಿಕ್ (ಜಾರ್ಜಿಯಾ)',
        'os_RU' => 'ಒಸ್ಸೆಟಿಕ್ (ರಷ್ಯಾ)',
        'pa' => 'ಪಂಜಾಬಿ',
        'pa_Arab' => 'ಪಂಜಾಬಿ (ಅರೇಬಿಕ್)',
        'pa_Arab_PK' => 'ಪಂಜಾಬಿ (ಅರೇಬಿಕ್, ಪಾಕಿಸ್ತಾನ)',
        'pa_Guru' => 'ಪಂಜಾಬಿ (ಗುರ್ಮುಖಿ)',
        'pa_Guru_IN' => 'ಪಂಜಾಬಿ (ಗುರ್ಮುಖಿ, ಭಾರತ)',
        'pa_IN' => 'ಪಂಜಾಬಿ (ಭಾರತ)',
        'pa_PK' => 'ಪಂಜಾಬಿ (ಪಾಕಿಸ್ತಾನ)',
        'pl' => 'ಪೊಲಿಶ್',
        'pl_PL' => 'ಪೊಲಿಶ್ (ಪೋಲ್ಯಾಂಡ್)',
        'ps' => 'ಪಾಷ್ಟೋ',
        'ps_AF' => 'ಪಾಷ್ಟೋ (ಅಫಘಾನಿಸ್ಥಾನ)',
        'ps_PK' => 'ಪಾಷ್ಟೋ (ಪಾಕಿಸ್ತಾನ)',
        'pt' => 'ಪೋರ್ಚುಗೀಸ್',
        'pt_AO' => 'ಪೋರ್ಚುಗೀಸ್ (ಅಂಗೋಲಾ)',
        'pt_BR' => 'ಪೋರ್ಚುಗೀಸ್ (ಬ್ರೆಜಿಲ್)',
        'pt_CH' => 'ಪೋರ್ಚುಗೀಸ್ (ಸ್ವಿಟ್ಜರ್ಲ್ಯಾಂಡ್)',
        'pt_CV' => 'ಪೋರ್ಚುಗೀಸ್ (ಕೇಪ್ ವರ್ಡೆ)',
        'pt_GQ' => 'ಪೋರ್ಚುಗೀಸ್ (ಈಕ್ವೆಟೋರಿಯಲ್ ಗಿನಿ)',
        'pt_GW' => 'ಪೋರ್ಚುಗೀಸ್ (ಗಿನಿ-ಬಿಸ್ಸಾವ್)',
        'pt_LU' => 'ಪೋರ್ಚುಗೀಸ್ (ಲಕ್ಸೆಂಬರ್ಗ್)',
        'pt_MO' => 'ಪೋರ್ಚುಗೀಸ್ (ಮಕಾವು SAR ಚೈನಾ)',
        'pt_MZ' => 'ಪೋರ್ಚುಗೀಸ್ (ಮೊಜಾಂಬಿಕ್)',
        'pt_PT' => 'ಪೋರ್ಚುಗೀಸ್ (ಪೋರ್ಚುಗಲ್)',
        'pt_ST' => 'ಪೋರ್ಚುಗೀಸ್ (ಸಾವೋ ಟೋಮ್ ಮತ್ತು ಪ್ರಿನ್ಸಿಪಿ)',
        'pt_TL' => 'ಪೋರ್ಚುಗೀಸ್ (ಟಿಮೋರ್ ಲೆಸ್ಟೆ)',
        'qu' => 'ಕ್ವೆಚುವಾ',
        'qu_BO' => 'ಕ್ವೆಚುವಾ (ಬೊಲಿವಿಯಾ)',
        'qu_EC' => 'ಕ್ವೆಚುವಾ (ಈಕ್ವೆಡಾರ್)',
        'qu_PE' => 'ಕ್ವೆಚುವಾ (ಪೆರು)',
        'rm' => 'ರೊಮಾನ್ಶ್',
        'rm_CH' => 'ರೊಮಾನ್ಶ್ (ಸ್ವಿಟ್ಜರ್ಲ್ಯಾಂಡ್)',
        'rn' => 'ರುಂಡಿ',
        'rn_BI' => 'ರುಂಡಿ (ಬುರುಂಡಿ)',
        'ro' => 'ರೊಮೇನಿಯನ್',
        'ro_MD' => 'ರೊಮೇನಿಯನ್ (ಮೊಲ್ಡೋವಾ)',
        'ro_RO' => 'ರೊಮೇನಿಯನ್ (ರೊಮೇನಿಯಾ)',
        'ru' => 'ರಷ್ಯನ್',
        'ru_BY' => 'ರಷ್ಯನ್ (ಬೆಲಾರಸ್)',
        'ru_KG' => 'ರಷ್ಯನ್ (ಕಿರ್ಗಿಸ್ಥಾನ್)',
        'ru_KZ' => 'ರಷ್ಯನ್ (ಕಝಾಕಿಸ್ಥಾನ್)',
        'ru_MD' => 'ರಷ್ಯನ್ (ಮೊಲ್ಡೋವಾ)',
        'ru_RU' => 'ರಷ್ಯನ್ (ರಷ್ಯಾ)',
        'ru_UA' => 'ರಷ್ಯನ್ (ಉಕ್ರೈನ್)',
        'rw' => 'ಕಿನ್ಯಾರ್‌ವಾಂಡಾ',
        'rw_RW' => 'ಕಿನ್ಯಾರ್‌ವಾಂಡಾ (ರುವಾಂಡಾ)',
        'sa' => 'ಸಂಸ್ಕೃತ',
        'sa_IN' => 'ಸಂಸ್ಕೃತ (ಭಾರತ)',
        'sc' => 'ಸರ್ಡೀನಿಯನ್',
        'sc_IT' => 'ಸರ್ಡೀನಿಯನ್ (ಇಟಲಿ)',
        'sd' => 'ಸಿಂಧಿ',
        'sd_Arab' => 'ಸಿಂಧಿ (ಅರೇಬಿಕ್)',
        'sd_Arab_PK' => 'ಸಿಂಧಿ (ಅರೇಬಿಕ್, ಪಾಕಿಸ್ತಾನ)',
        'sd_Deva' => 'ಸಿಂಧಿ (ದೇವನಾಗರಿ)',
        'sd_Deva_IN' => 'ಸಿಂಧಿ (ದೇವನಾಗರಿ, ಭಾರತ)',
        'sd_IN' => 'ಸಿಂಧಿ (ಭಾರತ)',
        'sd_PK' => 'ಸಿಂಧಿ (ಪಾಕಿಸ್ತಾನ)',
        'se' => 'ಉತ್ತರ ಸಾಮಿ',
        'se_FI' => 'ಉತ್ತರ ಸಾಮಿ (ಫಿನ್‌ಲ್ಯಾಂಡ್)',
        'se_NO' => 'ಉತ್ತರ ಸಾಮಿ (ನಾರ್ವೆ)',
        'se_SE' => 'ಉತ್ತರ ಸಾಮಿ (ಸ್ವೀಡನ್)',
        'sg' => 'ಸಾಂಗೋ',
        'sg_CF' => 'ಸಾಂಗೋ (ಮಧ್ಯ ಆಫ್ರಿಕಾ ಗಣರಾಜ್ಯ)',
        'sh' => 'ಸರ್ಬೋ-ಕ್ರೊಯೇಶಿಯನ್',
        'sh_BA' => 'ಸರ್ಬೋ-ಕ್ರೊಯೇಶಿಯನ್ (ಬೋಸ್ನಿಯಾ ಮತ್ತು ಹರ್ಜೆಗೋವಿನಾ)',
        'si' => 'ಸಿಂಹಳ',
        'si_LK' => 'ಸಿಂಹಳ (ಶ್ರೀಲಂಕಾ)',
        'sk' => 'ಸ್ಲೋವಾಕ್',
        'sk_SK' => 'ಸ್ಲೋವಾಕ್ (ಸ್ಲೊವಾಕಿಯಾ)',
        'sl' => 'ಸ್ಲೋವೇನಿಯನ್',
        'sl_SI' => 'ಸ್ಲೋವೇನಿಯನ್ (ಸ್ಲೋವೇನಿಯಾ)',
        'sn' => 'ಶೋನಾ',
        'sn_ZW' => 'ಶೋನಾ (ಜಿಂಬಾಬ್ವೆ)',
        'so' => 'ಸೊಮಾಲಿ',
        'so_DJ' => 'ಸೊಮಾಲಿ (ಜಿಬೂಟಿ)',
        'so_ET' => 'ಸೊಮಾಲಿ (ಇಥಿಯೋಪಿಯಾ)',
        'so_KE' => 'ಸೊಮಾಲಿ (ಕೀನ್ಯಾ)',
        'so_SO' => 'ಸೊಮಾಲಿ (ಸೊಮಾಲಿಯಾ)',
        'sq' => 'ಅಲ್ಬೇನಿಯನ್',
        'sq_AL' => 'ಅಲ್ಬೇನಿಯನ್ (ಅಲ್ಬೇನಿಯಾ)',
        'sq_MK' => 'ಅಲ್ಬೇನಿಯನ್ (ಉತ್ತರ ಮ್ಯಾಸಿಡೋನಿಯಾ)',
        'sr' => 'ಸೆರ್ಬಿಯನ್',
        'sr_BA' => 'ಸೆರ್ಬಿಯನ್ (ಬೋಸ್ನಿಯಾ ಮತ್ತು ಹರ್ಜೆಗೋವಿನಾ)',
        'sr_Cyrl' => 'ಸೆರ್ಬಿಯನ್ (ಸಿರಿಲಿಕ್)',
        'sr_Cyrl_BA' => 'ಸೆರ್ಬಿಯನ್ (ಸಿರಿಲಿಕ್, ಬೋಸ್ನಿಯಾ ಮತ್ತು ಹರ್ಜೆಗೋವಿನಾ)',
        'sr_Cyrl_ME' => 'ಸೆರ್ಬಿಯನ್ (ಸಿರಿಲಿಕ್, ಮೊಂಟೆನೆಗ್ರೋ)',
        'sr_Cyrl_RS' => 'ಸೆರ್ಬಿಯನ್ (ಸಿರಿಲಿಕ್, ಸೆರ್ಬಿಯಾ)',
        'sr_Latn' => 'ಸೆರ್ಬಿಯನ್ (ಲ್ಯಾಟಿನ್)',
        'sr_Latn_BA' => 'ಸೆರ್ಬಿಯನ್ (ಲ್ಯಾಟಿನ್, ಬೋಸ್ನಿಯಾ ಮತ್ತು ಹರ್ಜೆಗೋವಿನಾ)',
        'sr_Latn_ME' => 'ಸೆರ್ಬಿಯನ್ (ಲ್ಯಾಟಿನ್, ಮೊಂಟೆನೆಗ್ರೋ)',
        'sr_Latn_RS' => 'ಸೆರ್ಬಿಯನ್ (ಲ್ಯಾಟಿನ್, ಸೆರ್ಬಿಯಾ)',
        'sr_ME' => 'ಸೆರ್ಬಿಯನ್ (ಮೊಂಟೆನೆಗ್ರೋ)',
        'sr_RS' => 'ಸೆರ್ಬಿಯನ್ (ಸೆರ್ಬಿಯಾ)',
        'su' => 'ಸುಂಡಾನೀಸ್',
        'su_ID' => 'ಸುಂಡಾನೀಸ್ (ಇಂಡೋನೇಶಿಯಾ)',
        'su_Latn' => 'ಸುಂಡಾನೀಸ್ (ಲ್ಯಾಟಿನ್)',
        'su_Latn_ID' => 'ಸುಂಡಾನೀಸ್ (ಲ್ಯಾಟಿನ್, ಇಂಡೋನೇಶಿಯಾ)',
        'sv' => 'ಸ್ವೀಡಿಷ್',
        'sv_AX' => 'ಸ್ವೀಡಿಷ್ (ಆಲ್ಯಾಂಡ್ ದ್ವೀಪಗಳು)',
        'sv_FI' => 'ಸ್ವೀಡಿಷ್ (ಫಿನ್‌ಲ್ಯಾಂಡ್)',
        'sv_SE' => 'ಸ್ವೀಡಿಷ್ (ಸ್ವೀಡನ್)',
        'sw' => 'ಸ್ವಹಿಲಿ',
        'sw_CD' => 'ಸ್ವಹಿಲಿ (ಕಾಂಗೋ - ಕಿನ್ಶಾಸಾ)',
        'sw_KE' => 'ಸ್ವಹಿಲಿ (ಕೀನ್ಯಾ)',
        'sw_TZ' => 'ಸ್ವಹಿಲಿ (ತಾಂಜೇನಿಯಾ)',
        'sw_UG' => 'ಸ್ವಹಿಲಿ (ಉಗಾಂಡಾ)',
        'ta' => 'ತಮಿಳು',
        'ta_IN' => 'ತಮಿಳು (ಭಾರತ)',
        'ta_LK' => 'ತಮಿಳು (ಶ್ರೀಲಂಕಾ)',
        'ta_MY' => 'ತಮಿಳು (ಮಲೇಶಿಯಾ)',
        'ta_SG' => 'ತಮಿಳು (ಸಿಂಗಪುರ್)',
        'te' => 'ತೆಲುಗು',
        'te_IN' => 'ತೆಲುಗು (ಭಾರತ)',
        'tg' => 'ತಾಜಿಕ್',
        'tg_TJ' => 'ತಾಜಿಕ್ (ತಜಿಕಿಸ್ತಾನ್)',
        'th' => 'ಥಾಯ್',
        'th_TH' => 'ಥಾಯ್ (ಥೈಲ್ಯಾಂಡ್)',
        'ti' => 'ಟಿಗ್ರಿನ್ಯಾ',
        'ti_ER' => 'ಟಿಗ್ರಿನ್ಯಾ (ಎರಿಟ್ರಿಯಾ)',
        'ti_ET' => 'ಟಿಗ್ರಿನ್ಯಾ (ಇಥಿಯೋಪಿಯಾ)',
        'tk' => 'ಟರ್ಕ್‌ಮೆನ್',
        'tk_TM' => 'ಟರ್ಕ್‌ಮೆನ್ (ತುರ್ಕಮೆನಿಸ್ತಾನ್)',
        'tl' => 'ಟ್ಯಾಗಲೋಗ್',
        'tl_PH' => 'ಟ್ಯಾಗಲೋಗ್ (ಫಿಲಿಫೈನ್ಸ್)',
        'to' => 'ಟೋಂಗನ್',
        'to_TO' => 'ಟೋಂಗನ್ (ಟೊಂಗಾ)',
        'tr' => 'ಟರ್ಕಿಶ್',
        'tr_CY' => 'ಟರ್ಕಿಶ್ (ಸೈಪ್ರಸ್)',
        'tr_TR' => 'ಟರ್ಕಿಶ್ (ಟರ್ಕಿ)',
        'tt' => 'ಟಾಟರ್',
        'tt_RU' => 'ಟಾಟರ್ (ರಷ್ಯಾ)',
        'ug' => 'ಉಯಿಘರ್',
        'ug_CN' => 'ಉಯಿಘರ್ (ಚೀನಾ)',
        'uk' => 'ಉಕ್ರೇನಿಯನ್',
        'uk_UA' => 'ಉಕ್ರೇನಿಯನ್ (ಉಕ್ರೈನ್)',
        'ur' => 'ಉರ್ದು',
        'ur_IN' => 'ಉರ್ದು (ಭಾರತ)',
        'ur_PK' => 'ಉರ್ದು (ಪಾಕಿಸ್ತಾನ)',
        'uz' => 'ಉಜ್ಬೇಕ್',
        'uz_AF' => 'ಉಜ್ಬೇಕ್ (ಅಫಘಾನಿಸ್ಥಾನ)',
        'uz_Arab' => 'ಉಜ್ಬೇಕ್ (ಅರೇಬಿಕ್)',
        'uz_Arab_AF' => 'ಉಜ್ಬೇಕ್ (ಅರೇಬಿಕ್, ಅಫಘಾನಿಸ್ಥಾನ)',
        'uz_Cyrl' => 'ಉಜ್ಬೇಕ್ (ಸಿರಿಲಿಕ್)',
        'uz_Cyrl_UZ' => 'ಉಜ್ಬೇಕ್ (ಸಿರಿಲಿಕ್, ಉಜ್ಬೇಕಿಸ್ಥಾನ್)',
        'uz_Latn' => 'ಉಜ್ಬೇಕ್ (ಲ್ಯಾಟಿನ್)',
        'uz_Latn_UZ' => 'ಉಜ್ಬೇಕ್ (ಲ್ಯಾಟಿನ್, ಉಜ್ಬೇಕಿಸ್ಥಾನ್)',
        'uz_UZ' => 'ಉಜ್ಬೇಕ್ (ಉಜ್ಬೇಕಿಸ್ಥಾನ್)',
        'vi' => 'ವಿಯೆಟ್ನಾಮೀಸ್',
        'vi_VN' => 'ವಿಯೆಟ್ನಾಮೀಸ್ (ವಿಯೆಟ್ನಾಮ್)',
        'wo' => 'ವೋಲೋಫ್',
        'wo_SN' => 'ವೋಲೋಫ್ (ಸೆನೆಗಲ್)',
        'xh' => 'ಕ್ಸೋಸ',
        'xh_ZA' => 'ಕ್ಸೋಸ (ದಕ್ಷಿಣ ಆಫ್ರಿಕಾ)',
        'yi' => 'ಯಿಡ್ಡಿಶ್',
        'yi_001' => 'ಯಿಡ್ಡಿಶ್ (ಪ್ರಪಂಚ)',
        'yo' => 'ಯೊರುಬಾ',
        'yo_BJ' => 'ಯೊರುಬಾ (ಬೆನಿನ್)',
        'yo_NG' => 'ಯೊರುಬಾ (ನೈಜೀರಿಯಾ)',
        'zh' => 'ಚೈನೀಸ್',
        'zh_CN' => 'ಚೈನೀಸ್ (ಚೀನಾ)',
        'zh_HK' => 'ಚೈನೀಸ್ (ಹಾಂಗ್ ಕಾಂಗ್ SAR ಚೈನಾ)',
        'zh_Hans' => 'ಚೈನೀಸ್ (ಸರಳೀಕೃತ)',
        'zh_Hans_CN' => 'ಚೈನೀಸ್ (ಸರಳೀಕೃತ, ಚೀನಾ)',
        'zh_Hans_HK' => 'ಚೈನೀಸ್ (ಸರಳೀಕೃತ, ಹಾಂಗ್ ಕಾಂಗ್ SAR ಚೈನಾ)',
        'zh_Hans_MO' => 'ಚೈನೀಸ್ (ಸರಳೀಕೃತ, ಮಕಾವು SAR ಚೈನಾ)',
        'zh_Hans_SG' => 'ಚೈನೀಸ್ (ಸರಳೀಕೃತ, ಸಿಂಗಪುರ್)',
        'zh_Hant' => 'ಚೈನೀಸ್ (ಸಾಂಪ್ರದಾಯಿಕ)',
        'zh_Hant_HK' => 'ಚೈನೀಸ್ (ಸಾಂಪ್ರದಾಯಿಕ, ಹಾಂಗ್ ಕಾಂಗ್ SAR ಚೈನಾ)',
        'zh_Hant_MO' => 'ಚೈನೀಸ್ (ಸಾಂಪ್ರದಾಯಿಕ, ಮಕಾವು SAR ಚೈನಾ)',
        'zh_Hant_TW' => 'ಚೈನೀಸ್ (ಸಾಂಪ್ರದಾಯಿಕ, ತೈವಾನ್)',
        'zh_MO' => 'ಚೈನೀಸ್ (ಮಕಾವು SAR ಚೈನಾ)',
        'zh_SG' => 'ಚೈನೀಸ್ (ಸಿಂಗಪುರ್)',
        'zh_TW' => 'ಚೈನೀಸ್ (ತೈವಾನ್)',
        'zu' => 'ಜುಲು',
        'zu_ZA' => 'ಜುಲು (ದಕ್ಷಿಣ ಆಫ್ರಿಕಾ)',
    ],
];
